========
Ecoscope
========

Ecoscope is open-source analytical reporting framework for conservation.
The project is still under active development.

Copyright & License
-------------------

Ecoscope is licensed under BSD 3-Clause license. Copyright (c) 2021, wildlife-dynamics.
